---
title: 취소된 거래 원복방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제취소/환불
seo:
  title: 취소된 거래 원복방법
  description: >-
    원복기능은 PG사별로, 결제특성별로 가능여부가 상이합니다. 포트원의 안내에 따라 원복이 가능한 전제조건과 지원 가능한 PG사마다 제공되는
    원복기능들을 확인해보세요.
  keywords:
    - 일반결제
tags:
  - 공통
  - 결제취소-환불
pgCompanies:
  - 공통
searchTags:
  - 환불복구
  - 취소복구
  - 취소원복
  - 원복방법
  - 원복
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="취소된 거래 건의 원복 기능을 지원하는 결제대행사와 취소 원복을 위한 정책을 안내드립니다. " />

### **취소 원복이 불가한 경우**

1. 체크카드, 기프트카드, 에스크로 거래 인 경우
2. 당일 결제 건을 당일 취소한 경우

### **취소 원복 가능기한**

반드시 취소 처리한 당일 내 원복이 진행되어야 하며, 하루라도 지나면 원복이 불가하오니 원복 기한을 유념하여 주시기 바랍니다.

#### **나이스페이먼츠**

[나이스페이먼츠 상점관리자페이지 보러가기↗](https://npg.nicepay.co.kr/logIn.do)

- 기준 : 원복 기능. 지원 가능하나 부분 취소 시 원복 불가능
- 원복 방법 : 나이스페이 상점관리자페이지 > 거래내역 > TID 클릭 후 '원복' 버튼



#### NHN KCP

[NHN KCP 상점관리자페이지 보러가기↗](https://partner.kcp.co.kr/auth/login)

- 기준 : 원복 가능. 단, 매입 후 취소 또는 부분취소건 당일 원복 가능
- 원복 방법 : NHN KCP 상점관리자페이지  > 결제관리 > 일반결제 > 신용카드 > 거래내역조회 \
  \> 상세검색 > 거래번호로 조회 > 주문번호 클릭 > '취소원복' 버튼



#### **KG이니시스**

[KG이니시스 상점관리자페이지 보러가기↗](https://iniweb.inicis.com/security/login.do)

- 원복 기준 : 원복 가능. 단, 체크카드, 기프트카드, 휴대폰 소액결제, 페이코, 에스크로 거래일 경우 취소 원복 불가능하며 부분 취소 거래인 경우, 최종 부분 취소 거래부터 원복 가능.\
  매입 후 취소한 당일만 원복 가능하며, 이외 거래들은 원복 버튼 노출 되지 않음.
- 원복 방법
  - KG이니시스 상점관리자 페이지 > 통합 승인내역 조회 > 조회 리스트 내 TID 버튼 > TID 상세 팝업 \
    (부분 취소 시 부분 취소 건의 TID 선택해야 합니다)



- KG이니시스 상점관리자페이지 > 가맹점관리자 > 신용카드 > 승인내역조회 > 조회 리스트 내 TID 버튼 > TID 상세 팝업



#### **다날**

[다날 상점관리자페이지 보러가기↗](https://partner.danalpay.com/)

- 원복 방법 : 취소처리된 당일내 다날 고객센터(1566-3355) 혹은 포트원으로 원복 요청

#### **헥토파이낸셜**

[헥토파이낸셜 상점관리자페이지 보러가기↗](http://www.settlebank.co.kr/common/CommonMultiAction.do?_method=homeMain)

- 기준 : 당일 승인된 건의 당일 취소의 경우 원복 불가\
  ex) 4월9일 승인, 4월9일 취소
  - **카드결제** : 아래의 요건을 충족하는 경우 원복 가능
    - 거래일자이후 취소 요청
      (ex) 월요일 승인,  수요일 취소요청)
    - 취소 당일 원복 요청 (평일만 해당, 주말 및 공휴일 불가)
    - 평일 근무시간내 08시\~15시 이내 요청\
      (근무시간 외 접속 불가하며 원복 요청 건에 대해 별도 제외 처리 작업 필요, 외부 접속 불가함)
  - **계좌이체 :** 원복불가 (실시간 환불진행으로 원복 불가)
  - 가상계좌 : 일부 원복 가능
    - 환불 실행전에만 처리 가능 (별도 제외처리 필요)
    - 평일에만 가능
- 원복방법 : 헥토파이낸셜 측으로 아래 내용과 함께 원복 요청 (수신메일 : <pg_biz@settlebank.co.kr>)
- 취소 원복 요청 시 필요사항
  - 거래일자 :
  - 승인번호 :
  - 승인금액 :
  - 요청사유 : ex) 오등록

#### **네이버페이**

네이버페이 정책으로 인한 원복 기능 미지원

#### **페이코**

페이코 정책으로 인한 원복 기능 미지원

#### **토스페이먼츠**

토스페이먼츠 고객센터를 통해 원복 요청 가능

- 1544-7772 - 2 - 4 (계약 여부 및 심사 관련)
- 1544-7772 - 2 - 5 (기술지원 및 결제 오류)
- <support@tosspayments.com>
